==> kari-0.23.tar.gz: kari-0.23/alyson/init.c <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "version.h"
#include "globals.h"
#include "getopt.h"
#include "utils.h"
#include "init.h"

/*****************************************************************************
 * function  : parse_opt
 * arguments : arvc and argv
 * results   : option index pointing to URL argument, if any
 * purpose   : parses command line options, using GNU getopt_long()
 * caveats   : 
 ***************************************************************************** */

int
parse_opt (int argc, char **argv)
{
  char *debug_argument;
  int c;

  while (1)
    {
      int option_index = 0;
      static struct option long_options[] =
      {
	{"debug", required_argument, NULL, 'D'},
	{"help", no_argument, NULL, 'h'},
	{"version", no_argument, NULL, 'V'},
	{0, 0, 0, 0}
      };

      c = getopt_long (argc, argv, "D:hV",
		       long_options, &option_index);
      if (c == EOF)
	break;

      switch (c)
	{
	case 'D':
	  if (!strcmp (optarg, "help"))
	    debug_help();
	  else
	    {
	      debug_level = strtoul (optarg, &debug_argument, 8);
	      if (*debug_argument)
		{
		  error ("--debug requires an octal argument");
		  usage (1);
		}
	    }
	  break;
	case 'h':
	  usage (0);
	  break;
	case 'V':
	  /* FIXME: s/Alyson/YAWN/ when it's more worthy of the name */
	  fprintf (stderr, "Alyson version %0.2f\n", VERSION);
	  exit (0);
	  break;
	case '?':
	  /* Ambiguous option found. getopt_long() will bitch at the
	   * user for us, we just need to exit with usage info. */
	  usage (1);
	  break;

	default:
	  break;
	}
    }

  /* Check for <= 1 argument */
  if (optind < (argc - 1))
    {
      error ("please specify only one URL");
      usage (1);
    }

  return optind;

}

/*****************************************************************************
 * function  : usage
 * arguments : exit code
 * results   : 
 * purpose   : print usage information and exit with given exit code
 * caveats   : 
 ***************************************************************************** */

void
usage (int status)
{

  fprintf (status ? stderr : stdout, "Usage: %s [-DhV] [URL]\n\
-D --debug=<octal value>     enable debug output - see -Dhelp or --debug=help\n\
-h --help                    give this help\n\
-V --version                 display version number\n", program_name);

  exit (status);

}

==> kari-0.30.tar.gz: kari-0.30/alyson/init.c <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "config.h"
#include "globals.h"
#include "getopt.h"
#include "utils.h"
#include "init.h"

/*****************************************************************************
 * function  : parse_opt
 * arguments : arvc and argv
 * results   : option index pointing to URL argument, if any
 * purpose   : parses command line options, using GNU getopt_long()
 * caveats   : 
 ***************************************************************************** */

int
parse_opt (int argc, char **argv)
{
  char *debug_argument;
  int c;

  while (1)
    {
      int option_index = 0;
      static struct option long_options[] =
      {
	{"debug", required_argument, NULL, 'D'},
	{"help", no_argument, NULL, 'h'},
	{"version", no_argument, NULL, 'V'},
	{0, 0, 0, 0}
      };

      c = getopt_long (argc, argv, "D:hV",
		       long_options, &option_index);
      if (c == EOF)
	break;

      switch (c)
	{
	case 'D':
	  if (!strcmp (optarg, "help"))
	    debug_help();
	  else
	    {
	      debug_level = strtoul (optarg, &debug_argument, 8);
	      if (*debug_argument)
		{
		  error ("--debug requires an octal argument");
		  usage (1);
		}
	    }
	  break;
	case 'h':
	  usage (0);
	  break;
	case 'V':
	  /* FIXME: s/Alyson/YAWN/ when it's more worthy of the name */
	  fprintf (stderr, "Alyson version %s\n", VERSION);
	  exit (0);
	  break;
	case '?':
	  /* Ambiguous option found. getopt_long() will bitch at the
	   * user for us, we just need to exit with usage info. */
	  usage (1);
	  break;

	default:
	  break;
	}
    }

  /* Check for <= 1 argument */
  if (optind < (argc - 1))
    {
      error ("please specify only one URL");
      usage (1);
    }

  return optind;

}

/*****************************************************************************
 * function  : usage
 * arguments : exit code
 * results   : 
 * purpose   : print usage information and exit with given exit code
 * caveats   : 
 ***************************************************************************** */

void
usage (int status)
{

  fprintf (status ? stderr : stdout, "Usage: %s [-DhV] [URL]\n\
-D --debug=<octal value>     enable debug output - see -Dhelp or --debug=help\n\
-h --help                    give this help\n\
-V --version                 display version number\n", program_name);

  exit (status);

}
